@@ -1,4 +1,4 @@
-import os
+#!/usr/bin/env python3
 from sklearn.preprocessing import MinMaxScaler, StandardScaler
 import joblib
 import numpy as np
@@ -23,9 +23,9 @@ class Regbot:
 
 
   @classmethod  
-  def prepareInput(cls,opening,closing,volume):
-    avr = closing*volume/(opening + closing)
-    bvr = opening*volume/(opening + closing)
+  def prepareInput(cls,opening,closing):
+    avr = closing/(opening + closing)
+    bvr = opening/(opening + closing)
     testdata = np.array([[avr,bvr]])
     scaler = joblib.load(f'{cls.model_scaler_path}')
     testdata = scaler.transform(testdata)
@@ -34,18 +34,18 @@ class Regbot:
 
 
   @classmethod
-  def buySignalGenerator(cls,opening,closing,volume):
-    scalledInput = cls.prepareInput(opening,closing,volume)
-    return (cls.loadmodel().predict_proba(scalledInput)[:,1] >= 0.14285714285714285).astype(int)
+  def buySignalGenerator(cls,opening,closing):
+    scalledInput = cls.prepareInput(opening,closing)
+    return (cls.loadmodel().predict(scalledInput) > 0.0).astype(int)[0]
     
 
 
 
 
 
-def signal(opening,closing,volume):
+def signal(opening,closing):
   try:
-    return Regbot.buySignalGenerator(opening,closing,volume)[0]
+    return Regbot.buySignalGenerator(opening,closing)
   except Exception as e:
     print(e)
 
